let fs = require('fs/promises')
let path = require('path')

/**
 * Everything in the Headless UI codebase is written in TypeScript, however the
 * `@headlessui/tailwindcss` plugin has to compile to a CommonJs file. This works great, however
 * the types that were generated by tsc use `export default _default` instead of `export =
 * _default` even if we use `module: CommonJs` in the `tsconfig.json`
 *
 * Don't want to spend too much time on this problem, so doing this little hack to change the
 * exported type. This allows us to use the `@headlessui/tailwindcss` plugin and have types in a
 * CommonJs environment.
 **/

let types = path.resolve(__dirname, '..', 'dist', 'index.d.ts')

async function run() {
  let contents = await fs.readFile(types, 'utf8')
  contents = contents.replace('export default', 'export =')
  await fs.writeFile(types, contents, 'utf8')
}

run()
